#line 2 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/lexer.c"

#line 4 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/lexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
typedef uint64_t flex_uint64_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (yy_size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 154
#define YY_END_OF_BUFFER 155
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[1149] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      155,  153,   96,   99,  153,  153,  153,  153,  153,  101,
      101,  153,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  153,   96,  153,  152,  151,  152,  152,  111,
      109,  111,   98,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,
       96,  153,   97,   96,  153,    0,  106,    0,    0,  107,
        0,  101,    0,  105,  102,  105,  108,  100,  102,    0,
      102,  101,    0,   61,  104,  104,  104,  104,  104,  104,

      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,   62,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      110,  104,  104,  104,  104,  104,  104,  104,   76,  104,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,    0,    0,    0,    0,    0,    0,  102,   73,
      105,  102,  100,  102,    0,  102,  103,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,

      104,   39,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   14,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  104,  104,  104,  104,  104,  104,
       75,  104,  104,  104,  104,  104,  104,  104,   84,  104,
      104,  104,  104,  104,    0,    0,  102,   52,  104,  104,
      104,  104,   37,   35,  104,  104,  104,   45,  104,  104,
      104,  104,   40,  104,  104,  104,  104,  104,  104,  104,

      104,  104,  104,  104,  104,  104,   50,  104,  104,  104,
       43,  104,    1,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    9,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  150,  104,   94,  104,  104,  104,  104,  104,
      104,  104,   80,  104,  104,  104,  104,  104,   87,  104,
      104,   10,  104,  104,  104,  104,  104,   24,   48,  104,
      104,   51,   59,   41,  104,  104,  104,  104,  104,   38,
      104,  104,  104,   32,  104,  104,  104,   56,  104,  104,

      104,  104,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   95,  104,  104,  104,  104,  104,  104,  104,  104,
       82,  104,  104,  104,  104,  104,  104,  104,  104,   34,
      104,  104,   42,  104,  104,  104,  104,  104,   26,  104,
       46,   60,   49,   25,  104,  104,  104,  104,  104,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      104,  104,  104,   74,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,   33,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,  104,   28,  104,
       29,  104,   53,  104,   44,   36,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   15,    0,
        0,    0,    0,    0,    0,   19,    0,    0,   21,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,   93,  104,   31,  104,  104,  104,
      104,  104,  104,  104,  104,  104,   57,  104,   55,  104,
       58,   47,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  112,    0,    0,    0,    0,  117,   12,    0,
        0,    0,  147,    0,   16,    0,    0,   17,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  148,
        0,    0,    0,    0,    0,    0,    0,  104,  104,  104,
      104,   78,   79,   81,  104,  104,  104,  104,  104,  104,
       30,  104,  104,  104,  104,  104,  104,  104,  104,  104,

       54,   27,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   22,    0,   23,  127,    0,
        0,  124,    0,    0,    0,  104,  104,  104,  104,  104,
       85,   86,  104,  104,   71,  104,  104,   66,   65,  104,
      104,  104,   69,  104,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  145,
       11,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   20,    0,    0,    0,  142,    0,

        0,    0,    0,    0,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,   68,   64,   72,  146,    2,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   18,  128,  126,    0,  141,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  104,  104,  104,  104,  104,
      104,  104,   70,  104,   63,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  133,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  104,  104,  104,

      104,  104,  104,  104,  104,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  140,    0,    0,    0,    0,
        0,  144,    0,    0,    0,    0,  104,  104,  104,  104,
      104,  104,  104,   67,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   13,    0,    0,    0,    0,  129,    0,    0,
        0,    0,    0,  104,  104,  104,  104,   83,  104,  104,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  132,    0,    0,

        0,    0,  119,    0,    0,    0,    0,  104,   91,  104,
      104,  104,   89,  134,    0,    0,    0,    0,    0,    3,
        0,    0,    0,    0,    6,    7,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  130,    0,    0,  104,  104,
      104,  104,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    8,    0,    0,  123,    0,  118,    0,    0,    0,
        0,    0,  104,  104,   77,  104,    0,    0,  138,    0,
        0,    0,    0,  114,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  104,  104,   88,    0,    0,    0,
        0,    0,    0,    0,    0,  116,    0,  121,    0,    0,

        0,  131,    0,  104,  104,  139,  136,    0,  135,  113,
        0,    0,    0,    0,    0,    0,  125,  149,  104,  104,
      137,    0,    0,    0,  143,    0,    0,  104,  104,  115,
        0,    0,    0,  120,   90,  104,    4,    0,  122,  104,
        0,  104,    0,  104,    5,  104,   92,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    1,    1,    6,    1,    7,    8,
        9,   10,   11,    1,   12,   13,   14,   15,   16,   16,
       16,   16,   16,   16,   16,   16,   16,   17,    1,    1,
        1,    1,    1,    1,   18,   19,   20,   21,   22,   23,
       24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
       34,   35,   36,   37,   38,   39,   40,   28,   41,   42,
        1,   43,    1,    1,   44,    1,   45,   46,   47,   48,

       49,   50,   51,   52,   53,   28,   54,   55,   56,   57,
       58,   59,   28,   60,   61,   62,   63,   64,   65,   66,
       67,   68,    1,   69,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[70] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    3,    3,    3,    4,    4,    1,    4,    4,    4,
        4,    4,    4,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    1,    3,    4,    4,    4,    4,    4,    4,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    1
    } ;

static yyconst flex_int16_t yy_base[1157] =
    {   0,
        0,   68, 2660,   69,   70,   73,   75,   75, 2654,   80,
     2661, 2664, 2664, 2664,   73,   82,   77,   87,   77,  127,
     2594, 2642,   82,   93,   96,  101,  134,  139,  154,  145,
      105,  160,  166,  171,  174,  182,  186,  204,  212,  208,
      218,  221, 2589,  202,  262, 2664, 2664,  205, 2635, 2664,
     2664, 2642, 2664,  224,  230,  238,  261,  290,  296,  308,
      311,  314,  317,  320,  323,  330,  359,  364,  333,  374,
      208, 2633, 2664,  252, 2632,  149, 2664, 2650,  260, 2664,
      154, 2586,  177,  379,  384,  233, 2664,    0,  387,  369,
     2664, 2664,    0, 2664,  406,  416,  426,  429,  434,  437,

      440,  443,  446,  449,  459,  462,  465,  468,  477,  480,
      484,  487,  495,  492,  501,  504,  514,  517,  524,  520,
      539,  542,  545,  554,  558,  566,  573, 2664,  305,    0,
       64, 2625, 2592,  106,  182,  265,  240, 2596,  310, 2595,
      377,  535, 2602, 2597,  108, 2588, 2591,  350, 2621, 2585,
     2664,  584,  588,  594,  597,  600,  608,  614,  617,  620,
      623,  628,  632,  641,  644,  648,  651,  657,  660,  665,
      669,  672,  395, 2619, 2574,  462, 2617,  196,  678,  282,
      695,  303,    0,  699,  186,  714,    0,  683,  721,  726,
      729,  732,  744,  747,  753,  756,  762,  765,  771,  776,

      779,  782,  785,  793,  797,  803,  813,  816,  821,  825,
      831,  834,  837,  840,  846,  849,  852,  860,  864,  856,
      871,  875, 2612, 2590, 2574,  326,  427, 2585, 2587, 2585,
      501, 2587, 2574,   84, 2568, 2581, 2664, 2569,  530, 2580,
     2567, 2563, 2576, 2576,  295, 2561,  306, 2568, 2558, 2563,
     2559, 2564, 2556, 2567,  878,  881,  898,  901,  909,  912,
      915,  919,  922,  931,  934,  937,  945,  948,  951,  957,
      962,  973,  965,  979, 2566,  983,  989, 1003, 1006, 1011,
     1014, 1017, 1020, 1024, 1029, 1035, 1043, 1046, 1049, 1052,
     1056, 1059, 1062, 1065, 1068, 1071, 1074, 1079, 1082, 1091,

     1094, 1105, 1115, 1129, 1133, 1121, 1136, 1139, 1142, 1145,
     1148, 1151, 2664, 2564, 2554, 2562, 2561, 2550, 2544, 2540,
     2561, 2544, 2664, 2555, 2545, 2542, 2539, 2555, 2544, 2538,
     2577, 2547, 2537, 2539, 2531, 2530, 2542, 2531, 2537, 2525,
     2533, 2524, 2534, 2522,  493, 2524, 2521, 2561, 2531, 2530,
     2516, 2515, 2664, 1157, 1160, 1165, 1168, 1171, 1177, 1182,
     1185, 1188, 1191, 1201, 1204, 1207, 1216, 1219, 1224, 1229,
     1237, 2664, 1241, 1244, 1254, 1264, 1273, 1269, 1283, 1286,
     1289, 1294, 1298, 1301, 1304, 1307, 1310, 1313, 1317, 1320,
     1325, 1328, 1331, 1334, 1337, 1340, 1343, 1353, 1361, 1365,

     1369, 1373, 2515, 2542, 2512, 2518, 2514, 2522, 2517, 2506,
     2506, 2508, 2506, 2520, 2501, 2508, 2513, 2516, 2502, 2528,
     2498, 2494, 2503, 2510, 2497, 2504, 2494, 2496, 2495, 2499,
     2495, 2521, 2489, 2496, 2495, 2494, 2484, 2486,  349,  207,
     2477, 1377, 1382, 1385, 1392, 1395, 1399, 1406, 1411, 1416,
     1419, 1422, 1425, 1428, 1431, 1436, 1440, 1448, 1451, 1463,
     1481, 1470, 1454, 1491, 1494, 1507, 1510, 1513, 1516, 1519,
     1522, 1528, 1533, 1536, 1539, 1542, 1548, 1554, 1557, 2478,
     2471, 1538, 2488, 2475, 2475, 2477, 2478, 2472, 2469, 2468,
     2482, 2468, 2474, 2481, 2461, 2476, 2478, 2460, 2473, 2475,

     2462, 2457, 2469, 2468, 2466, 2465, 2455, 2455, 2454, 2457,
     2447, 2448, 2487, 2458, 2452, 2446,  594, 2445, 2444, 2456,
     1569, 1572, 1575, 1581, 1586, 1590, 1593, 1598, 1601, 1604,
     1611, 1614, 1617, 1626, 1635, 1639, 1645, 1648, 1657, 1664,
     1667, 1675, 1683, 1686, 1689, 1692, 1695, 1701, 1704, 1707,
     1716, 1720, 1723, 1726, 1731, 1734, 2480, 2468, 2435, 2445,
     2447, 2446, 2434, 2448, 2439, 2429, 2439, 2427, 2435, 2434,
     2437, 2423, 2435, 2422, 2422, 2432, 2431, 2423, 2664, 2429,
     2420, 2405, 2402, 2413, 2429,  569, 2428, 2387, 2664, 2392,
     2382, 2391, 2379, 2382, 2390, 2381, 2389, 2391, 2378, 2386,

     2372, 2375, 1737, 1745, 1750, 1753, 1758, 1763, 1766, 1769,
     1772, 1775, 1778, 1787, 1796, 1801, 1806, 1813, 1821, 1834,
     1816, 1843, 1825, 1846, 1849, 1852, 1855, 1859, 1863, 1871,
     1874, 1877, 2371, 2383, 2377, 2381, 2380, 2373, 2370, 2361,
     2359,  487, 2664,  750, 2363, 2357, 2365, 2664, 2664, 2367,
     2383, 2342, 2664, 2346, 2664, 2340, 2343, 2664, 2323, 2326,
     2321, 2316, 2302, 2303, 2289, 2289, 2252, 2237, 2255, 2664,
     2248, 2247, 2240, 2221, 2233, 2198,  669, 1880, 1883, 1886,
     1889, 1892, 1897, 1900, 1903, 1908, 1914, 1923, 1926, 1929,
     1932, 1935, 1941, 1947, 1950, 1953, 1969, 1964, 1982, 1985,

     1988, 1993, 2211, 2187, 2192, 2173, 2161, 2188, 2144, 2151,
     2150, 2137, 2138, 2136, 2127, 2099, 2084, 2090, 2067,  524,
     2060, 2062, 2039, 2022, 2021, 2060, 2010, 2018, 2016, 2018,
     2006, 1991, 1986, 1958, 1944, 2664, 1941, 2664, 2664, 1937,
     1965, 2664, 1954, 1929, 1912, 1996, 1999, 2002, 2005, 2008,
     2011, 2014, 2018, 2021, 2024, 2029, 2032, 2035, 2044, 2048,
     2059, 2062, 2065, 2073, 1922, 1920, 1919, 1937, 1932, 1892,
     1884, 1912, 1900, 1866,  241, 1876, 1871, 1845, 1822, 2664,
     2664, 1831, 1811, 1800, 1801, 1795, 1784, 1778, 1764, 1768,
     1767, 1762, 1758, 1756, 2664, 1758, 1747, 1776, 2664, 1735,

     1735, 1716,   79, 1708, 2076, 2079, 2082, 2085, 2089, 2092,
     2095, 2099, 2102, 2113, 2105, 2116, 2119, 2664, 2664, 1700,
     1692, 1690, 1689, 1722, 1663, 1667, 1667, 1659, 1644, 1649,
     1634, 1646, 1636, 1637, 1615, 1614, 1617, 1644, 1618, 1593,
     1606, 2664, 2664, 2664, 1601, 2664, 1591, 1591, 1578, 1613,
     1584, 1574, 1565, 1561, 1538, 2126, 2132, 2139, 2142, 2145,
     2148, 2151, 2154, 2157, 2160, 1571, 1540, 1529, 1520, 1513,
     1522, 1516, 1526, 1497, 1479, 1475, 1467, 1452, 1452, 1463,
     1460, 1440, 2664, 1434, 1441, 1433, 1436, 1421, 1426, 1417,
     1426, 1412, 1409, 1401, 1435, 1374, 1361, 2163, 2166, 2169,

     2175, 2178, 2190, 2199, 2202, 1358, 1365, 1353, 1339, 1350,
     1342, 1308, 1303, 1348, 1313, 1301, 1306, 1291, 1266, 1255,
     1268, 1272, 1241, 1239, 1221, 2664, 1253, 1209, 1224, 1214,
     1214, 2664, 1197, 1189, 1197, 1219, 2205, 2208, 2213, 2216,
     2224, 2227, 2233, 2236, 1191, 1186, 1178, 1206, 1174, 1174,
     1155, 1150, 1152, 1172, 1122, 1110, 1080, 1070, 1071, 1077,
     1067, 1075, 2664, 1065, 1062, 1070, 1052, 2664, 1063, 1062,
     1061, 1040, 1054, 2239, 2250, 2243, 2254, 2257, 2264, 2260,
     1040,  994,  992,  993,  996,  984,  972,  964,  965,  950,
      950,  951,  951,  937,  969,  931,  934, 2664,  961,  924,

      905,  913, 2664,  906,  904,  932,  884, 2267, 2273, 2277,
     2281, 2288, 2294, 2664,  920,  918,  889,  856,  888, 2664,
      886,  843,  854,  849, 2664, 2664,  849,  839,  824,  830,
      798,  806,  788,  782,  811, 2664,  765,  774, 2303, 2306,
     2309, 2312,  761,  755,  763,  783,  743,  742,  720,  714,
      580, 2664,  714,  734, 2664,  705, 2664,  693,  693,  689,
      688,  676, 2315, 2318, 2321, 2324,  678,  675, 2664,  662,
      671,  669,  685, 2664,   21,   71,   95,  123,  179,  198,
      250,  257,  263,  289, 2327, 2333, 2336,  304,  340,  347,
      355,  356,  357,  365,  393, 2664,  418, 2664,  449,  429,

      453, 2664,  451, 2341, 2344, 2664, 2664,  490, 2664, 2664,
      492,  490,  507,  524,  516,  533, 2664, 2664, 2350, 2355,
     2664,  543,  572,  578, 2664,  576,  589, 2359, 2369, 2664,
      586,  597,  617, 2664, 2363, 2374, 2664,  604, 2664, 2384,
      638, 2387,  650, 2397, 2664, 2393, 2405, 2664, 2453, 2457,
     2461, 2465, 2467, 2469, 2473,  698
    } ;

static yyconst flex_int16_t yy_def[1157] =
    {   0,
     1148,    1, 1149, 1149, 1150, 1150,    1,    7,    1,    1,
     1148, 1148, 1148, 1148, 1151, 1152, 1148, 1153, 1148, 1148,
       20, 1148, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1148,   45, 1148, 1148,   45, 1151, 1148, 1151, 1152, 1148,
     1148,   20, 1153, 1153, 1153, 1153, 1148, 1155, 1148, 1148,
     1148, 1148, 1156, 1148, 1154, 1154, 1154, 1154, 1154, 1154,

     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1148, 1148,   45,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1148,   45, 1148, 1148,   45, 1148, 1148, 1153,
     1153, 1153, 1155, 1148, 1148, 1148, 1156, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,

     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1148, 1153, 1153, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,

     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1148, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,

     1154, 1154, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,

     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,

     1148, 1148, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,

     1154, 1154, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,

     1148, 1148, 1148, 1148, 1154, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1154, 1154, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1154, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1154, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1154, 1154, 1154,

     1154, 1154, 1154, 1154, 1154, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1154, 1154, 1154, 1154,
     1154, 1154, 1154, 1154, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1154, 1154, 1154, 1154, 1154, 1154, 1154,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,

     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1154, 1154, 1154,
     1154, 1154, 1154, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1154, 1154,
     1154, 1154, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1154, 1154, 1154, 1154, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1154, 1154, 1154, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,

     1148, 1148, 1148, 1154, 1154, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1154, 1154,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1154, 1154, 1148,
     1148, 1148, 1148, 1148, 1154, 1154, 1148, 1148, 1148, 1154,
     1148, 1154, 1148, 1154, 1148, 1154, 1154,    0, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148
    } ;

static yyconst flex_int16_t yy_nxt[2734] =
    {   0,
       12,   13,   14,   13,   15,   12,   16,   12,   12,   12,
       12,   17,   18,   19,   20,   21,   22,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       24,   23,   25,   26,   23,   27,   23,   23,   23,   23,
       23,   23,   12,   23,   23,   28,   29,   30,   31,   32,
       23,   23,   33,   23,   34,   23,   35,   36,   37,   23,
       38,   39,   40,   41,   42,   23,   23,   23,   43,   44,
       48,   47,   51,   45,   49,   51,   71,   77, 1094,   52,
       72,   74,   52,   53,   80,   75,   87,   73,   80,   81,
       88,   82,   82,   83,   86,   83,  223,   54,   83,   84,

       83,   85,   85,  329,   83,   86,   83,   83,   86,   83,
      224,   55,   83,   86,   83,   78,   83,   86,   83,   56,
      330,   57,   58, 1095,   59,   60,  225,   61,   62,   63,
       96,   64,   65,  853,   66,   67,   68,   69,   70,   89,
      854,   82,   82, 1096,   98,   83,   86,   83,   90,   91,
       83,   86,   83,   77,  228,   92,   83,   86,   83,   99,
      250,  105,   97,  229,   92,   83,   86,   83,  179,  179,
      106,   83,   86,   83,  251,   90,   91,   83,   86,   83,
     1097,   92,   83,   86,   83,   83,   86,   83,   83,   92,
       83,   78,   93,   83,   86,   83,  100,   83,   86,   83,

      186,  186,  104,  129,  107,  101,  148,  130,  102,  173,
      149,  103,  108,  174,  109,   83,   86,   83,  112,   83,
       86,   83,  110,   83,   86,   83,  518, 1098,  111,   83,
       86,   83,   83,   86,   83,   83,   86,   83,  230,  519,
      113,   83,   86,   83,   83,  114,   83,  231,  115,   83,
       86,   83,  275,  176, 1099,  116,  117,  177,  118,  234,
      120,  231,   80,  121,  124,  119,   80,  127,  152, 1100,
      125,  122,   83,   86,   83,  126,  828,  829,  123,  131,
      132,  133,  134,  135,  136,  137,  138,  139,  235,  153,
      140,  141,  154,   83,  142,   83,  143,  144,  145,  146,

      147,   83,   86,   83, 1101,  155,  129,   83,   86,   83,
      130, 1102,  101,  232,   83,  102,   83,  233,  103,   83,
       86,   83,   83,   86,   83,   83,   86,   83,   83,   86,
       83,   83,   86,   83,   83,   86,   83, 1103,  156,  342,
      107,   83,   86,   83,   83,   86,   83,  104,  108,  316,
      109,  148, 1106,  157,  345,  149,  158,  343,  159,  237,
      317,  161,  160,  346,  163,  238,  239,  110,  516,  162,
       83,   86,   83,  517,  111,   83,   86,   83,  166,  185,
      185,  164,  165,  186,  186,   83,   86,   83, 1107,  124,
       83,  180,   83,  171, 1108,   83,  173,   83,   85,   85,

      174,  184,  184, 1109, 1110,  181,  182,  167,   90,   91,
      116,  168,  120,  118, 1111,  121,  169,   83,   86,   83,
      119,  241,  172,  122, 1112,  242,  125,   83,   86,   83,
      170,  126,  181,  182,  243,   90,   91,   83,   86,   83,
       83,   86,   83, 1113,  188,   83,   86,   83,   83,   86,
       83,   83,   86,   83,   83,   86,   83,   83,   86,   83,
       83,   86,   83,  176,  190, 1114,  191,  177, 1115,  189,
       83,   86,   83,   83,   86,   83,   83,   86,   83,   83,
       86,   83,  318,  319,  193,  320, 1116,  194,   83,   86,
       83,   83,   86,   83,  192,   83,   86,   83,   83,   86,

       83, 1117,  195,   83,   86,   83,   83,   86,   83,  712,
     1118,  196,   83,   86,   83,   83,   86,   83,  433,  199,
      198,  197,  434,  713,  200,   83,   86,   83,   83,   86,
       83,   83,   86,   83,  201,   83,   86,   83, 1121, 1122,
      203,  202,  204,  205,  206, 1123,  208,  324,  782,  207,
       83,   86,   83,   83,   86,   83,   83,   86,   83,  325,
      783,  209,  326, 1124,  210,   83,   86,   83,  213,   83,
       86,   83, 1125, 1126,  212,  215,  334,   83,   86,   83,
     1127,  211,  335,  214,   83,   86,   83,  244,  661,  245,
      336, 1130,  246,  662,  247,   83,   86,   83,  216,   83,

       86,   83, 1075,  218,  217,   83,   86,   83,   83,   86,
       83,   83,   86,   83,  219, 1076, 1131,  220,  221,   83,
       86,   83, 1132, 1133,  222,   83,   86,   83,   83,   86,
       83,   83,   86,   83,   83,   86,   83, 1134,  255,   83,
       86,   83,  598,   83,   86,   83,  599, 1137,  257,  259,
      256,  258,   83,   86,   83,   83,   86,   83, 1138,   83,
       86,   83,   83,   86,   83, 1139, 1141,  260,   83,   86,
       83,   83,   86,   83,  264,  261,   83,   86,   83,  263,
       83,   86,   83,   83,   86,   83,  262,  265,  744,  205,
      745,  267,  179,  179,   83,   86,   83, 1143, 1145,   90,

       91,  187,  266,  268, 1093,  185,  276,  270,   83,  277,
      277,  278,  269,  184,  184,  271, 1092,  273, 1091, 1090,
       90,   91, 1089,  272,  211, 1088,   90,   91,  186,  186,
     1084,  274,   83,   86,   83, 1083,   91,   83,   86,   83,
       83,   86,   83,   83,   86,   83, 1082,   90,   91, 1081,
     1080,  280, 1079, 1078,  281,   83,   86,   83,   83,   86,
       83, 1077, 1074,   91,   83,   86,   83,   83,   86,   83,
      714,  715,  282,   83,   86,   83,   83,   86,   83,  716,
     1073,  279,   83,   86,   83,  717,  283,   83,   86,   83,
       83,   86,   83,   83,   86,   83,   83,   86,   83, 1072,

     1071,  287, 1070,  284,   83,   86,   83,  285,   83,   86,
       83, 1069, 1068,  286,   83,   86,   83,  288, 1067,  289,
      291, 1062, 1061,  292,   83,   86,   83,   83,   86,   83,
     1060,  290,   83,   86,   83,  293,   83,   86,   83, 1059,
     1058,  294,   83,   86,   83,   83,   86,   83,   83,   86,
       83,   83,   86,   83, 1057, 1056,  295,   83,   86,   83,
       83,   86,   83,   83,   86,   83,  296,   83,   86,   83,
      298,   83,   86,   83,  297,   83,   86,   83, 1055,  301,
      299,  300,   83,   86,   83, 1054,   83,   86,   83,   83,
       86,   83,   83,   86,   83,  302, 1053, 1052,  303, 1051,

      307, 1050,  304, 1049,  305, 1048,  306, 1047,  308,   83,
       86,   83,   83,   86,   83, 1046,  309,  310,  311,  312,
       83,   86,   83,   83,   86,   83,   83,   86,   83,  355,
       83,   86,   83,   83,   86,   83, 1045, 1044,  354, 1043,
     1038,  356,   83,   86,   83,   83,   86,   83,   83,   86,
       83, 1037, 1036,  358, 1035,  357,   83,   86,   83,   83,
       86,   83,   83,   86,   83, 1034, 1033,  359,   83,   86,
       83, 1032,  361,   83,   86,   83,   83,   86,   83,  362,
     1031, 1030,  363,  360,   83,   86,   83, 1029, 1028,  364,
       83,   86,   83,  365,   83, 1027,   83,  277,  277, 1026,

       83, 1025,   83,  277,  277,  366, 1024, 1023,  370, 1022,
      368,  182, 1021,  367,   83,   86,   83,   83,   86,   83,
     1020,  369,   83,   86,   83,   83,   86,   83,   83,   86,
       83,   83,   86,   83,  374,   83,   86,   83,  182,  371,
       83,   86,   83, 1019, 1018,  375,   83,   86,   83,  376,
     1017, 1016,  377, 1015,   83,   86,   83,   83,   86,   83,
       83,   86,   83,   83,   86,   83,  373,   83,   86,   83,
       83,   86,   83,   83,   86,   83,   83,   86,   83,   83,
       86,   83,   83,   86,   83,   83,   86,   83, 1014,  378,
       83,   86,   83,   83,   86,   83,  379,  380, 1007, 1006,

      382,  381,   83,   86,   83,   83,   86,   83, 1005, 1004,
      383, 1003,  386, 1002, 1001,  387,   83,   86,   83, 1000,
      384,  999,  388,  998,  997,  385,   83,   86,   83,  996,
      995,  389,   83,   86,   83,  391,  994,  393,  993,  392,
       83,   86,   83,  390,   83,   86,   83,   83,   86,   83,
       83,   86,   83,   83,   86,   83,   83,   86,   83,   83,
       86,   83,   83,   86,   83,  394,  992,  395,   83,   86,
       83,   83,   86,   83,  991,  396,   83,   86,   83,   83,
       86,   83,   83,   86,   83,  398,  399,  397,   83,   86,
       83,  990,  400,   83,   86,   83,   83,   86,   83,   83,

       86,   83,   83,   86,   83,  442,  989,  401,  988,  987,
      402,  444,   83,   86,   83,   83,   86,   83,   83,   86,
       83,  446,  986,  985,  443,  984,  983,   83,   86,   83,
       83,   86,   83,  445,  982,   83,   86,   83,  981,  447,
       83,   86,   83,  973,  449,  972,  971,  448,   83,   86,
       83,  385,   83,   86,   83,   83,   86,   83,  450,  970,
      453,  969,  968,  451,  392,   83,   86,   83,  967,  966,
      452,  399,  965,  455,  459,   83,   86,   83,  964,  454,
       83,   86,   83,  456,   83,   86,   83,  963,  962,  457,
      460,  961,  960,  458,   83,   86,   83,   83,   86,   83,

       83,   86,   83,  959,  461,   83,   86,   83,  462,   83,
       86,   83,   83,   86,   83,   83,   86,   83,   83,   86,
       83,   83,   86,   83,   83,   86,   83,  958,   83,   86,
       83,   83,   86,   83,  463,  464,   83,   86,   83,   83,
       86,   83,   83,   86,   83,   83,   86,   83,   83,   86,
       83,   83,   86,   83,   83,   86,   83,  957,  956,  468,
      955,  954,  465,  469,   83,   86,   83,  953,  466,  952,
      951,  467,   83,   86,   83,  471,   83,   86,   83,  470,
       83,   86,   83,  473,   83,   86,   83,  475,   83,   86,
       83,  950,  472,   83,   86,   83,   83,   86,   83,  949,

      948,  474,  947,   83,   86,   83,   83,   86,   83,  476,
       83,   86,   83,  478,  946,  945,  479,   83,   86,   83,
      936,  477,   83,   86,   83,  935,  521,   83,   86,   83,
       83,   86,   83,   83,   86,   83,   83,   86,   83,   83,
       86,   83,   83,   86,   83,  522,  523,   83,   86,   83,
      526,   83,   86,   83,  934,  933,  524,  932,  525,   83,
       86,   83,   83,   86,   83,   83,   86,   83,  536,  931,
      529,  527,  528,  930,   83,   86,   83,  929,  928,  470,
      927,   83,   86,   83,  926,  925,  530,  924,  533,  531,
      532,  923,   83,   86,   83,  545,  922,  534,  537,  538,

      539,  540,   83,   86,   83,   83,   86,   83,  921,  541,
      920,  919,  542,  918,  917,  535,  543,  544,   83,   86,
       83,   83,   86,   83,   83,   86,   83,   83,   86,   83,
       83,   86,   83,   83,   86,   83,  916,  915,  547,   83,
       86,   83,  914,  546,   83,   86,   83,   83,   86,   83,
       83,   86,   83,   83,   86,   83,  559,  560,  549,   83,
       86,   83,  913,  912,  548,   83,   86,   83,   83,   86,
       83,  911,  561,  562,  550,  910,  909,  563,  908,  551,
       83,   86,   83,   83,   86,   83,   83,   86,   83,  907,
      906,  553,   83,   86,   83,  897,  554,   83,   86,   83,

      552,   83,   86,   83,   83,   86,   83,  896,  555,   83,
       86,   83,   83,   86,   83,   83,   86,   83,  556,  895,
      894,  603,   83,   86,   83,   83,   86,   83,   83,   86,
       83,  893,  892,  606,  604,  891,  605,   83,   86,   83,
      607,  608,  609,  890,  610,  889,   83,   86,   83,  888,
       83,   86,   83,  887,  886,  612,   83,   86,   83,   83,
       86,   83,  885,  884,  613,  883,  611,  617,   83,   86,
       83,  882,  614,  881,  619,   83,   86,   83,   83,   86,
       83,  880,  615,  616,  879,  618,   83,   86,   83,  620,
      878,  877,  621,  622,   83,   86,   83,   83,   86,   83,

       83,   86,   83,   83,   86,   83,   83,   86,   83,  876,
      875,  623,   83,   86,   83,   83,   86,   83,   83,   86,
       83,  874,  873,  624,  872,  871,  625,   83,   86,   83,
      626,   83,   86,   83,   83,   86,   83,   83,   86,   83,
      870,  628,   83,   86,   83,   83,   86,   83,   83,   86,
       83,  869,  868,  627,  867,  630,   83,   86,   83,  866,
      629,   83,   86,   83,   83,   86,   83,  855,  631,   83,
       86,   83,  852,  632,   83,   86,   83,   83,   86,   83,
       83,   86,   83,   83,   86,   83,   83,   86,   83,   83,
       86,   83,  851,  680,  850,  849,  681,  678,   83,   86,

       83,  848,  847,  679,  846,  845,  682,   83,   86,   83,
      844,  683,   83,   86,   83,  843,  842,   83,   86,   83,
      684,  841,  840,  685,   83,   86,   83,   83,   86,   83,
      687,  686,   83,   86,   83,  692,   83,   86,   83,  689,
      688,  691,  839,  838,  690,   83,   86,   83,  837,  693,
      697,  695,  836,  694,   83,   86,   83,   83,   86,   83,
       83,   86,   83,   83,   86,   83,   83,   86,   83,  696,
       83,   86,   83,  700,   83,   86,   83,  835,  698,  834,
      833,  699,   83,   86,   83,   83,   86,   83,   83,   86,
       83,   83,   86,   83,   83,   86,   83,   83,   86,   83,

       83,   86,   83,   83,   86,   83,  832,  701,   83,   86,
       83,   83,   86,   83,   83,   86,   83,  831,  702,   83,
       86,   83,  830,  827,  748,   83,   86,   83,  746,  826,
      825,  747,  824,  749,   83,   86,   83,   83,   86,   83,
       83,   86,   83,   83,   86,   83,   83,   86,   83,  823,
      822,  750,   83,   86,   83,  821,  751,  756,   83,   86,
       83,   83,   86,   83,   83,   86,   83,  820,  819,  757,
      818,  804,  752,  803,  760,   83,   86,   83,  753,  802,
       83,   86,   83,  758,  801,  800,  759,  754,  761,  799,
      755,  798,  762,   83,   86,   83,   83,   86,   83,   83,

       86,   83,  797,  763,   83,   86,   83,   83,   86,   83,
       83,   86,   83,   83,   86,   83,   83,   86,   83,   83,
       86,   83,   83,   86,   83,   83,   86,   83,  764,   83,
       86,   83,   83,   86,   83,   83,   86,   83,  796,  805,
       83,   86,   83,   83,   86,   83,   83,   86,   83,  813,
      812,  795,  809,  794,  807,   83,   86,   83,  806,   83,
       86,   83,  793,  792,  808,  791,  810,  814,  790,  811,
       83,   86,   83,   83,   86,   83,   83,   86,   83,  789,
      815,  788,  787,  816,   83,   86,   83,   83,   86,   83,
       83,   86,   83,   83,   86,   83,   83,   86,   83,  786,

       83,   86,   83,   83,   86,   83,   83,   86,   83,  817,
       83,   86,   83,   83,   86,   83,   83,   86,   83,  785,
      864,  784,  857,  781,   83,   86,   83,   83,   86,   83,
       83,   86,   83,  863,  856,  859,  860,   83,   86,   83,
      780,  858,  862,   83,   86,   83,  779,  778,  861,  865,
       83,   86,   83,   83,   86,   83,   83,   86,   83,   83,
       86,   83,   83,   86,   83,   83,   86,   83,   83,   86,
       83,   83,   86,   83,   83,   86,   83,   83,   86,   83,
       83,   86,   83,  777,  899,  905,   83,   86,   83,   83,
       86,   83,  898,  776,  904,  775,  774,  902,  773,  772,

      900,   83,   86,   83,  901,  771,  937,  770,  769,  903,
       83,   86,   83,   83,   86,   83,   83,   86,   83,   83,
       86,   83,  938,  944,   83,   86,   83,   83,   86,   83,
      940,  939,  768,  942,  941,   83,   86,   83,   83,   86,
       83,  767,  766,  943,   83,   86,   83,   83,   86,   83,
       83,   86,   83,  974,   83,   86,   83,  976,  765,  743,
      975,   83,   86,   83,  977,   83,   86,   83,   83,   86,
       83,   83,   86,   83,  978,   83,   86,   83,   83,   86,
       83,  742,  741,  979,   83,   86,   83,  740,   83,   86,
       83,  980,   83,   86,   83,  739,  738, 1010, 1040,   83,

       86,   83,  737,  736, 1008,   83,   86,   83, 1012,  735,
     1011, 1009, 1013, 1039,   83,   86,   83,   83,   86,   83,
       83,   86,   83,   83,   86,   83,   83,   86,   83,   83,
       86,   83,   83,   86,   83,   83,   86,   83,   83,   86,
       83,  734, 1041, 1042,   83,   86,   83,   83,   86,   83,
      733, 1063,   83,   86,   83,   83,   86,   83,  732,  731,
     1066,   83,   86,   83,  730, 1064,   83,   86,   83, 1065,
       83,   86,   83, 1085,   83,   86,   83, 1086,  729, 1129,
       83,   86,   83,  728, 1087,   83,   86,   83, 1104,  727,
     1105,  726,  725, 1119,  724,   83,   86,   83,   83,   86,

       83,  723,  722, 1120,   83,   86,   83, 1128,   83,   86,
       83,  721,  720, 1136,  719, 1135,   83,   86,   83,  718,
      711,  710,  709,  708,  707,  706,  705,  704,  703,  677,
     1140, 1142,  676,  675,  674,  673,  672,  671,  670,  669,
      668, 1144,  667,  666,  665, 1146,  664,  663,  660,  659,
      658,  657, 1147,   46,   46,   46,   46,   50,   50,   50,
       50,   76,   76,   76,   76,   79,   79,   79,   79,   86,
       86,   95,   95,  183,  656,  183,  183,  655,  654,  653,
      652,  651,  650,  649,  648,  647,  646,  645,  644,  643,
      642,  641,  640,  639,  638,  637,  636,  635,  634,  633,

      602,  601,  600,  597,  596,  595,  594,  593,  592,  591,
      590,  589,  588,  587,  586,  585,  584,  583,  582,  581,
      580,  579,  578,  577,  576,  575,  574,  573,  572,  571,
      570,  569,  568,  567,  566,  565,  564,  558,  557,  520,
      515,  514,  513,  512,  511,  510,  509,  508,  507,  506,
      505,  504,  503,  502,  501,  500,  499,  498,  497,  496,
      495,  494,  493,  492,  491,  490,  489,  488,  487,  486,
      485,  484,  483,  482,  481,  480,  441,  440,  439,  438,
      437,  436,  435,  432,  431,  430,  429,  428,  427,  426,
      425,  424,  423,  422,  421,  420,  419,  418,  417,  416,

      415,  414,  413,  412,  411,  410,  409,  408,  407,  406,
      405,  404,  403,  372,  353,  352,  351,  350,  349,  348,
      347,  344,  341,  340,  339,  338,  337,  333,  332,  331,
      328,  327,  323,  322,  321,  315,  314,  313,  178,  231,
      175,  254,  150,  253,  252,  249,  248,  240,  236,  227,
      226, 1148, 1148,  178,  175,  151,  150,  128,   94, 1148,
     1148,   73,   47,   11, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,

     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148
    } ;

static yyconst flex_int16_t yy_chk[2734] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        4,    4,    5,    2,    4,    6,    8,   15, 1075,    5,
        8,   10,    6,    7,   16,   10,   19,   10,   16,   17,
       19,   17,   17,   23,   23,   23,  131,    7,   18,   18,

       18,   18,   18,  234,   24,   24,   24,   25,   25,   25,
      131,    7,   26,   26,   26,   15,   31,   31,   31,    7,
      234,    7,    7, 1076,    7,    7,  131,    7,    7,    7,
       24,    7,    7,  803,    7,    7,    7,    7,    7,   20,
      803,   20,   20, 1077,   26,   27,   27,   27,   20,   20,
       28,   28,   28,   76,  134,   20,   30,   30,   30,   27,
      145,   31,   25,  134,   20,   29,   29,   29,   81,   81,
       31,   32,   32,   32,  145,   20,   20,   33,   33,   33,
     1078,   20,   34,   34,   34,   35,   35,   35,   83,   20,
       83,   76,   20,   36,   36,   36,   28,   37,   37,   37,

      185,  185,   30,   44,   32,   29,   48,   44,   29,   71,
       48,   29,   32,   71,   32,   38,   38,   38,   35,   40,
       40,   40,   33,   39,   39,   39,  440, 1079,   34,   41,
       41,   41,   42,   42,   42,   54,   54,   54,  135,  440,
       36,   55,   55,   55,   86,   37,   86,  135,   37,   56,
       56,   56,  178,   74, 1080,   38,   38,   74,   38,  137,
       39,  178,   79,   39,   40,   38,   79,   42,   54, 1081,
       41,   39,   57,   57,   57,   41,  775,  775,   39,   45,
       45,   45,   45,   45,   45,   45,   45,   45,  137,   55,
       45,   45,   56,  180,   45,  180,   45,   45,   45,   45,

       45,   58,   58,   58, 1082,   57,  129,   59,   59,   59,
      129, 1083,   57,  136,  182,   57,  182,  136,   57,   60,
       60,   60,   61,   61,   61,   62,   62,   62,   63,   63,
       63,   64,   64,   64,   65,   65,   65, 1084,   58,  245,
       59,   66,   66,   66,   69,   69,   69,   58,   59,  226,
       59,  148, 1088,   59,  247,  148,   60,  245,   61,  139,
      226,   63,   62,  247,   64,  139,  139,   61,  439,   63,
       67,   67,   67,  439,   63,   68,   68,   68,   66,   90,
       90,   65,   65,   90,   90,   70,   70,   70, 1089,   69,
       84,   84,   84,   69, 1090,   85,  173,   85,   85,   85,

      173,   89,   89, 1091, 1092,   85,   85,   67,   89,   89,
       67,   67,   68,   67, 1093,   68,   68,   95,   95,   95,
       67,  141,   70,   68, 1094,  141,   70,   96,   96,   96,
       68,   70,   85,   85,  141,   89,   89,   97,   97,   97,
       98,   98,   98, 1095,   96,   99,   99,   99,  100,  100,
      100,  101,  101,  101,  102,  102,  102,  103,  103,  103,
      104,  104,  104,  176,   98, 1097,   99,  176, 1099,   97,
      105,  105,  105,  106,  106,  106,  107,  107,  107,  108,
      108,  108,  227,  227,  101,  227, 1100,  102,  109,  109,
      109,  110,  110,  110,  100,  111,  111,  111,  112,  112,

      112, 1101,  103,  114,  114,  114,  113,  113,  113,  642,
     1103,  104,  115,  115,  115,  116,  116,  116,  345,  107,
      106,  105,  345,  642,  108,  117,  117,  117,  118,  118,
      118,  120,  120,  120,  109,  119,  119,  119, 1108, 1111,
      111,  110,  112,  113,  114, 1112,  115,  231,  720,  114,
      121,  121,  121,  122,  122,  122,  123,  123,  123,  231,
      720,  116,  231, 1113,  117,  124,  124,  124,  119,  125,
      125,  125, 1114, 1115,  118,  120,  239,  126,  126,  126,
     1116,  117,  239,  119,  127,  127,  127,  142,  586,  142,
      239, 1122,  142,  586,  142,  152,  152,  152,  121,  153,

      153,  153, 1051,  123,  122,  154,  154,  154,  155,  155,
      155,  156,  156,  156,  124, 1051, 1123,  125,  126,  157,
      157,  157, 1124, 1126,  127,  158,  158,  158,  159,  159,
      159,  160,  160,  160,  161,  161,  161, 1127,  152,  162,
      162,  162,  517,  163,  163,  163,  517, 1131,  154,  156,
      153,  155,  164,  164,  164,  165,  165,  165, 1132,  166,
      166,  166,  167,  167,  167, 1133, 1138,  157,  168,  168,
      168,  169,  169,  169,  162,  158,  170,  170,  170,  161,
      171,  171,  171,  172,  172,  172,  160,  163,  677,  164,
      677,  165,  179,  179,  188,  188,  188, 1141, 1143,  179,

      179, 1156,  164,  166, 1073,  181,  181,  168,  181,  181,
      181,  188,  167,  184,  184,  169, 1072,  171, 1071, 1070,
      184,  184, 1068,  170,  168, 1067,  179,  179,  186,  186,
     1062,  172,  189,  189,  189, 1061,  186,  190,  190,  190,
      191,  191,  191,  192,  192,  192, 1060,  184,  184, 1059,
     1058,  190, 1056, 1054,  190,  193,  193,  193,  194,  194,
      194, 1053, 1050,  186,  195,  195,  195,  196,  196,  196,
      644,  644,  191,  197,  197,  197,  198,  198,  198,  644,
     1049,  189,  199,  199,  199,  644,  192,  200,  200,  200,
      201,  201,  201,  202,  202,  202,  203,  203,  203, 1048,

     1047,  196, 1046,  193,  204,  204,  204,  194,  205,  205,
      205, 1045, 1044,  195,  206,  206,  206,  197, 1043,  198,
      200, 1038, 1037,  201,  207,  207,  207,  208,  208,  208,
     1035,  199,  209,  209,  209,  203,  210,  210,  210, 1034,
     1033,  204,  211,  211,  211,  212,  212,  212,  213,  213,
      213,  214,  214,  214, 1032, 1031,  205,  215,  215,  215,
      216,  216,  216,  217,  217,  217,  206,  220,  220,  220,
      208,  218,  218,  218,  207,  219,  219,  219, 1030,  211,
      209,  210,  221,  221,  221, 1029,  222,  222,  222,  255,
      255,  255,  256,  256,  256,  212, 1028, 1027,  213, 1024,

      217, 1023,  214, 1022,  215, 1021,  216, 1019,  218,  257,
      257,  257,  258,  258,  258, 1018,  219,  220,  221,  222,
      259,  259,  259,  260,  260,  260,  261,  261,  261,  256,
      262,  262,  262,  263,  263,  263, 1017, 1016,  255, 1015,
     1007,  257,  264,  264,  264,  265,  265,  265,  266,  266,
      266, 1006, 1005,  259, 1004,  258,  267,  267,  267,  268,
      268,  268,  269,  269,  269, 1002, 1001,  260,  270,  270,
      270, 1000,  263,  271,  271,  271,  273,  273,  273,  264,
      999,  997,  265,  262,  272,  272,  272,  996,  995,  266,
      274,  274,  274,  267,  276,  994,  276,  276,  276,  993,

      277,  992,  277,  277,  277,  268,  991,  990,  273,  989,
      271,  277,  988,  270,  278,  278,  278,  279,  279,  279,
      987,  272,  280,  280,  280,  281,  281,  281,  282,  282,
      282,  283,  283,  283,  280,  284,  284,  284,  277,  274,
      285,  285,  285,  986,  985,  281,  286,  286,  286,  282,
      984,  983,  282,  982,  287,  287,  287,  288,  288,  288,
      289,  289,  289,  290,  290,  290,  279,  291,  291,  291,
      292,  292,  292,  293,  293,  293,  294,  294,  294,  295,
      295,  295,  296,  296,  296,  297,  297,  297,  981,  285,
      298,  298,  298,  299,  299,  299,  286,  287,  973,  972,

      290,  289,  300,  300,  300,  301,  301,  301,  971,  970,
      291,  969,  295,  967,  966,  296,  302,  302,  302,  965,
      292,  964,  297,  962,  961,  294,  303,  303,  303,  960,
      959,  298,  306,  306,  306,  300,  958,  301,  957,  300,
      304,  304,  304,  299,  305,  305,  305,  307,  307,  307,
      308,  308,  308,  309,  309,  309,  310,  310,  310,  311,
      311,  311,  312,  312,  312,  302,  956,  303,  354,  354,
      354,  355,  355,  355,  955,  304,  356,  356,  356,  357,
      357,  357,  358,  358,  358,  306,  308,  305,  359,  359,
      359,  954,  309,  360,  360,  360,  361,  361,  361,  362,

      362,  362,  363,  363,  363,  354,  953,  310,  952,  951,
      312,  357,  364,  364,  364,  365,  365,  365,  366,  366,
      366,  359,  950,  949,  356,  948,  947,  367,  367,  367,
      368,  368,  368,  358,  946,  369,  369,  369,  945,  360,
      370,  370,  370,  936,  362,  935,  934,  361,  371,  371,
      371,  363,  373,  373,  373,  374,  374,  374,  364,  933,
      367,  931,  930,  365,  367,  375,  375,  375,  929,  928,
      366,  369,  927,  370,  374,  376,  376,  376,  925,  368,
      378,  378,  378,  370,  377,  377,  377,  924,  923,  371,
      375,  922,  921,  373,  379,  379,  379,  380,  380,  380,

      381,  381,  381,  920,  376,  382,  382,  382,  377,  383,
      383,  383,  384,  384,  384,  385,  385,  385,  386,  386,
      386,  387,  387,  387,  388,  388,  388,  919,  389,  389,
      389,  390,  390,  390,  380,  381,  391,  391,  391,  392,
      392,  392,  393,  393,  393,  394,  394,  394,  395,  395,
      395,  396,  396,  396,  397,  397,  397,  918,  917,  388,
      916,  915,  385,  389,  398,  398,  398,  914,  386,  913,
      912,  387,  399,  399,  399,  392,  400,  400,  400,  391,
      401,  401,  401,  395,  402,  402,  402,  397,  442,  442,
      442,  911,  393,  443,  443,  443,  444,  444,  444,  910,

      909,  396,  908,  445,  445,  445,  446,  446,  446,  399,
      447,  447,  447,  401,  907,  906,  402,  448,  448,  448,
      897,  400,  449,  449,  449,  896,  443,  450,  450,  450,
      451,  451,  451,  452,  452,  452,  453,  453,  453,  454,
      454,  454,  455,  455,  455,  444,  445,  456,  456,  456,
      448,  457,  457,  457,  895,  894,  446,  893,  447,  458,
      458,  458,  459,  459,  459,  463,  463,  463,  459,  892,
      452,  449,  450,  891,  460,  460,  460,  890,  889,  453,
      888,  462,  462,  462,  887,  886,  453,  885,  456,  454,
      455,  884,  461,  461,  461,  462,  882,  457,  460,  461,

      461,  461,  464,  464,  464,  465,  465,  465,  881,  461,
      880,  879,  461,  878,  877,  458,  461,  461,  466,  466,
      466,  467,  467,  467,  468,  468,  468,  469,  469,  469,
      470,  470,  470,  471,  471,  471,  876,  875,  465,  472,
      472,  472,  874,  464,  473,  473,  473,  474,  474,  474,
      475,  475,  475,  476,  476,  476,  482,  482,  467,  477,
      477,  477,  873,  872,  466,  478,  478,  478,  479,  479,
      479,  871,  482,  482,  468,  870,  869,  482,  868,  470,
      521,  521,  521,  522,  522,  522,  523,  523,  523,  867,
      866,  476,  524,  524,  524,  855,  477,  525,  525,  525,

      475,  526,  526,  526,  527,  527,  527,  854,  478,  528,
      528,  528,  529,  529,  529,  530,  530,  530,  479,  853,
      852,  521,  531,  531,  531,  532,  532,  532,  533,  533,
      533,  851,  850,  525,  522,  849,  523,  534,  534,  534,
      526,  527,  528,  848,  529,  847,  535,  535,  535,  845,
      536,  536,  536,  841,  840,  531,  537,  537,  537,  538,
      538,  538,  839,  838,  532,  837,  530,  536,  539,  539,
      539,  836,  533,  835,  539,  540,  540,  540,  541,  541,
      541,  834,  534,  535,  833,  538,  542,  542,  542,  540,
      832,  831,  541,  542,  543,  543,  543,  544,  544,  544,

      545,  545,  545,  546,  546,  546,  547,  547,  547,  830,
      829,  543,  548,  548,  548,  549,  549,  549,  550,  550,
      550,  828,  827,  544,  826,  825,  544,  551,  551,  551,
      545,  552,  552,  552,  553,  553,  553,  554,  554,  554,
      824,  547,  555,  555,  555,  556,  556,  556,  603,  603,
      603,  823,  822,  546,  821,  550,  604,  604,  604,  820,
      548,  605,  605,  605,  606,  606,  606,  804,  552,  607,
      607,  607,  802,  554,  608,  608,  608,  609,  609,  609,
      610,  610,  610,  611,  611,  611,  612,  612,  612,  613,
      613,  613,  801,  605,  800,  798,  606,  603,  614,  614,

      614,  797,  796,  604,  794,  793,  607,  615,  615,  615,
      792,  608,  616,  616,  616,  791,  790,  617,  617,  617,
      609,  789,  788,  610,  618,  618,  618,  621,  621,  621,
      612,  611,  619,  619,  619,  618,  623,  623,  623,  614,
      613,  617,  787,  786,  616,  620,  620,  620,  785,  619,
      623,  621,  784,  620,  622,  622,  622,  624,  624,  624,
      625,  625,  625,  626,  626,  626,  627,  627,  627,  622,
      628,  628,  628,  626,  629,  629,  629,  783,  624,  782,
      779,  625,  630,  630,  630,  631,  631,  631,  632,  632,
      632,  678,  678,  678,  679,  679,  679,  680,  680,  680,

      681,  681,  681,  682,  682,  682,  778,  628,  683,  683,
      683,  684,  684,  684,  685,  685,  685,  777,  630,  686,
      686,  686,  776,  774,  680,  687,  687,  687,  678,  773,
      772,  679,  771,  681,  688,  688,  688,  689,  689,  689,
      690,  690,  690,  691,  691,  691,  692,  692,  692,  770,
      769,  685,  693,  693,  693,  768,  686,  692,  694,  694,
      694,  695,  695,  695,  696,  696,  696,  767,  766,  693,
      765,  745,  687,  744,  696,  698,  698,  698,  688,  743,
      697,  697,  697,  694,  741,  740,  695,  689,  697,  737,
      690,  735,  698,  699,  699,  699,  700,  700,  700,  701,

      701,  701,  734,  699,  702,  702,  702,  746,  746,  746,
      747,  747,  747,  748,  748,  748,  749,  749,  749,  750,
      750,  750,  751,  751,  751,  752,  752,  752,  700,  753,
      753,  753,  754,  754,  754,  755,  755,  755,  733,  746,
      756,  756,  756,  757,  757,  757,  758,  758,  758,  757,
      756,  732,  750,  731,  748,  759,  759,  759,  747,  760,
      760,  760,  730,  729,  749,  728,  753,  760,  727,  754,
      761,  761,  761,  762,  762,  762,  763,  763,  763,  726,
      761,  725,  724,  762,  764,  764,  764,  805,  805,  805,
      806,  806,  806,  807,  807,  807,  808,  808,  808,  723,

      809,  809,  809,  810,  810,  810,  811,  811,  811,  764,
      812,  812,  812,  813,  813,  813,  815,  815,  815,  722,
      813,  721,  806,  719,  814,  814,  814,  816,  816,  816,
      817,  817,  817,  812,  805,  808,  809,  856,  856,  856,
      718,  807,  811,  857,  857,  857,  717,  716,  810,  814,
      858,  858,  858,  859,  859,  859,  860,  860,  860,  861,
      861,  861,  862,  862,  862,  863,  863,  863,  864,  864,
      864,  865,  865,  865,  898,  898,  898,  899,  899,  899,
      900,  900,  900,  715,  857,  864,  901,  901,  901,  902,
      902,  902,  856,  714,  862,  713,  712,  860,  711,  710,

      858,  903,  903,  903,  859,  709,  898,  708,  707,  861,
      904,  904,  904,  905,  905,  905,  937,  937,  937,  938,
      938,  938,  899,  905,  939,  939,  939,  940,  940,  940,
      901,  900,  706,  903,  902,  941,  941,  941,  942,  942,
      942,  705,  704,  904,  943,  943,  943,  944,  944,  944,
      974,  974,  974,  937,  976,  976,  976,  939,  703,  676,
      938,  975,  975,  975,  940,  977,  977,  977,  978,  978,
      978,  980,  980,  980,  941,  979,  979,  979, 1008, 1008,
     1008,  675,  674,  942, 1009, 1009, 1009,  673, 1010, 1010,
     1010,  943, 1011, 1011, 1011,  672,  671,  976, 1010, 1012,

     1012, 1012,  669,  668,  974, 1013, 1013, 1013,  979,  667,
      977,  975,  980, 1008, 1039, 1039, 1039, 1040, 1040, 1040,
     1041, 1041, 1041, 1042, 1042, 1042, 1063, 1063, 1063, 1064,
     1064, 1064, 1065, 1065, 1065, 1066, 1066, 1066, 1085, 1085,
     1085,  666, 1011, 1012, 1086, 1086, 1086, 1087, 1087, 1087,
      665, 1039, 1104, 1104, 1104, 1105, 1105, 1105,  664,  663,
     1042, 1119, 1119, 1119,  662, 1040, 1120, 1120, 1120, 1041,
     1128, 1128, 1128, 1063, 1135, 1135, 1135, 1064,  661, 1120,
     1129, 1129, 1129,  660, 1066, 1136, 1136, 1136, 1085,  659,
     1086,  657,  656, 1104,  654, 1140, 1140, 1140, 1142, 1142,

     1142,  652,  651, 1105, 1146, 1146, 1146, 1119, 1144, 1144,
     1144,  650,  647, 1129,  646, 1128, 1147, 1147, 1147,  645,
      641,  640,  639,  638,  637,  636,  635,  634,  633,  602,
     1136, 1140,  601,  600,  599,  598,  597,  596,  595,  594,
      593, 1142,  592,  591,  590, 1144,  588,  587,  585,  584,
      583,  582, 1146, 1149, 1149, 1149, 1149, 1150, 1150, 1150,
     1150, 1151, 1151, 1151, 1151, 1152, 1152, 1152, 1152, 1153,
     1153, 1154, 1154, 1155,  581, 1155, 1155,  580,  578,  577,
      576,  575,  574,  573,  572,  571,  570,  569,  568,  567,
      566,  565,  564,  563,  562,  561,  560,  559,  558,  557,

      520,  519,  518,  516,  515,  514,  513,  512,  511,  510,
      509,  508,  507,  506,  505,  504,  503,  502,  501,  500,
      499,  498,  497,  496,  495,  494,  493,  492,  491,  490,
      489,  488,  487,  486,  485,  484,  483,  481,  480,  441,
      438,  437,  436,  435,  434,  433,  432,  431,  430,  429,
      428,  427,  426,  425,  424,  423,  422,  421,  420,  419,
      418,  417,  416,  415,  414,  413,  412,  411,  410,  409,
      408,  407,  406,  405,  404,  403,  352,  351,  350,  349,
      348,  347,  346,  344,  343,  342,  341,  340,  339,  338,
      337,  336,  335,  334,  333,  332,  331,  330,  329,  328,

      327,  326,  325,  324,  322,  321,  320,  319,  318,  317,
      316,  315,  314,  275,  254,  253,  252,  251,  250,  249,
      248,  246,  244,  243,  242,  241,  240,  238,  236,  235,
      233,  232,  230,  229,  228,  225,  224,  223,  177,  175,
      174,  150,  149,  147,  146,  144,  143,  140,  138,  133,
      132,   82,   78,   75,   72,   52,   49,   43,   22,   21,
       11,    9,    3, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,

     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
/*
 * The SIP lexer.
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 *
 * This file is part of SIP.
 *
 * This copy of SIP is licensed for use under the terms of the SIP License
 * Agreement.  See the file LICENSE for more details.
 *
 * This copy of SIP may also used under the terms of the GNU General Public
 * License v2 or v3 as published by the Free Software Foundation which can be
 * found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
 *
 * SIP is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
#line 20 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>

#include "sip.h"
#include "parser.h"


#ifndef FLEX_SCANNER
#error "Only flex is supported at the moment"
#endif


/* Windows doesn't have unistd.h so declare it here. */
extern int isatty(int);


/* These are unused. */
static int input(void) SIP_UNUSED;
static void yy_fatal_error(yyconst char *) SIP_UNUSED;
static int yy_top_state(void) SIP_UNUSED;
static void yyunput(int, char *) SIP_UNUSED;

#define YY_NO_UNISTD_H
#define YY_FATAL_ERROR(s)       fatallex(s)

#define MAX_INCLUDE_DEPTH       10
#define MAX_CODE_LINE_LENGTH    1000


static struct inputFile {
    sourceLocation sloc;                /* The source location. */
    YY_BUFFER_STATE bs;                 /* The flex buffer state handle. */
    char *cwd;                          /* The path part of the file name. */
    parserContext pc;                   /* The parser context. */
} inputFileStack[MAX_INCLUDE_DEPTH];

static int currentFile;                 /* Index of the current input file. */
static char codeLine[MAX_CODE_LINE_LENGTH + 2]; /* The current code line. */
static int codeIdx;                     /* Index of next code character. */
static int parenDepth;                  /* The current depth of (...). */
static stringList *allFiles;            /* The list of all input files. */

static FILE *openFile(const char *);
static void fatallex(char *);




#line 1502 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/lexer.c"

#define INITIAL 0
#define code 1
#define ccomment 2
#define directive 3
#define directive_start 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state (int new_state );
    
    static void yy_pop_state (void );
    
    static int yy_top_state (void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		yy_size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 75 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"


#line 1704 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/lexer.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1149 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 2664 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 77 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_API;}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 78 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_AUTOPYNAME;}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 79 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_COMPOMODULE;}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 80 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFDOCSTRFMT;}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 81 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFDOCSTRSIG;}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 82 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFENCODING;}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 83 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFMETATYPE;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 84 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_DEFSUPERTYPE;}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 85 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_END;}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 86 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN INITIAL; return TK_END;}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 87 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_EXCEPTION;}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 88 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_FEATURE;}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 89 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_HIDE_NS;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 90 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_IF;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 91 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_IMPORT;}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 92 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_INCLUDE;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 93 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_LICENSE;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 94 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_MAPPEDTYPE;}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 95 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_MODULE;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 96 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_PLATFORMS;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 97 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_PLUGIN;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 98 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{BEGIN directive_start; return TK_PROPERTY;}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 99 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_TIMELINE;}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 101 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_CLASS;}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 102 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_STRUCT;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 103 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_PUBLIC;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 104 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_PROTECTED;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 105 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_PRIVATE;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 106 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNALS;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 107 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNALS;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 108 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNAL_METHOD;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 109 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_SLOTS;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 110 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_SLOTS;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 111 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_SLOT_METHOD;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 112 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_CHAR;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 113 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_WCHAR_T;}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 114 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_BOOL;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 115 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_SHORT;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 116 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_INT;}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 117 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_LONG;}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 118 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_FLOAT;}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 119 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_DOUBLE;}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 120 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_VOID;}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 121 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_VIRTUAL;}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 122 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_ENUM;}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 123 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNED;}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 124 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_UNSIGNED;}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 125 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_CONST;}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 126 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_STATIC;}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 127 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_TRUE_VALUE;}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 128 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_FALSE_VALUE;}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 129 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_NULL_VALUE;}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 130 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_TYPEDEF;}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 131 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_NAMESPACE;}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 132 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_OPERATOR;}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 133 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_THROW;}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 134 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_EXPLICIT;}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 135 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_TEMPLATE;}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 136 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_FINAL;}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 137 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_SIZET;}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 138 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_SCOPE;}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 139 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_LOGICAL_OR;}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 140 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_PYOBJECT;}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 141 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_PYTUPLE;}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 142 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_PYLIST;}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 143 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_PYDICT;}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 144 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_PYCALLABLE;}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 145 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_PYSLICE;}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 146 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_PYTYPE;}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 147 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_PYBUFFER;}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 148 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_PYSSIZET;}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 149 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* Remove in v5.1. */
    return TK_PYSSIZET;
}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 153 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_ELLIPSIS;}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 155 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_FORMAT;}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 156 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_GET;}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 157 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_ID;}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 158 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_KWARGS;}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 159 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_LANGUAGE;}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 160 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_LICENSEE;}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 161 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_NAME;}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 162 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_OPTIONAL;}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 163 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_ORDER;}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 164 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_REMOVELEADING;}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 165 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_SET;}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 166 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_SIGNATURE;}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 167 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_TIMESTAMP;}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 168 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_TYPE;}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 169 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_USEARGNAMES;}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 170 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_USELIMITEDAPI;}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 171 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_ALLRAISEPYEXC;}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 172 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_CALLSUPERINIT;}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 173 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_DEFERRORHANDLER;}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 174 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_VERSION;}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 176 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_TRUE_VALUE;}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 177 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{return TK_FALSE_VALUE;}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 180 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* Ignore whitespace. */
    ;
}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 185 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /*
     * Maintain the parenthesis depth so that we don't enter the 'code' state
     * until any arguments have been parsed.
     */
    ++parenDepth;

    BEGIN directive;

    return '(';
}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 197 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* Maintain the parenthesis depth. */
    --parenDepth;

    BEGIN INITIAL;

    return ')';
}
	YY_BREAK
case 99:
/* rule 99 can match eol */
YY_RULE_SETUP
#line 206 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* Maintain the line number. */
    ++inputFileStack[currentFile].sloc.linenr;

    if (codeIdx == 0 && parenDepth == 0)
    {
        BEGIN code;
    }
}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 216 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* Ignore C++ style comments. */
    ;
}
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 222 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* A signed decimal number. */
    yylval.number = strtol(yytext,NULL,0);
    return TK_NUMBER_VALUE;
}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 229 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* A floating point number. */
    yylval.real = strtod(yytext,NULL);
    return TK_REAL_VALUE;
}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 236 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* An unsigned hexadecimal number. */
    yylval.number = strtol(yytext,NULL,16);
    return TK_NUMBER_VALUE;
}
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 243 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* An identifier name. */
    yylval.text = sipStrdup(yytext);
    return TK_NAME_VALUE;
}
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 250 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* A relative pathname. */
    yylval.text = sipStrdup(yytext);
    return TK_PATH_VALUE;
}
	YY_BREAK
case 106:
/* rule 106 can match eol */
YY_RULE_SETUP
#line 257 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* A double-quoted string. */
    char ch, *dp, *sp;

    /*
     * Copy the string without the quotes and interpret any standard escape
     * characters.
     */
    yylval.text = sipMalloc(strlen(yytext) - 2 + 1);

    dp = yylval.text;
    sp = yytext + 1;

    while ((ch = *sp++) != '"' && ch != '\0')
    {
        if (ch == '\\')
        {
            ch = *sp++;

            if (ch == 'n')
                ch = '\n';
            else if (ch == 'r')
                ch = '\r';
            else if (ch == 't')
                ch = '\t';
        }

        *dp++ = ch;
    }

    *dp = '\0';

    return TK_STRING_VALUE;
}
	YY_BREAK
case 107:
/* rule 107 can match eol */
YY_RULE_SETUP
#line 293 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* A single-quoted character. */
    if (strlen(yytext) != 3)
        fatallex("Exactly one character expected between single quotes");

    yylval.qchar = yytext[1];

    return TK_QCHAR_VALUE;
}
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 304 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* Ignore C-style comments. */
    yy_push_state(ccomment);
}
	YY_BREAK
case 109:
/* rule 109 can match eol */
YY_RULE_SETUP
#line 308 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    ++inputFileStack[currentFile].sloc.linenr;
}
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 311 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    yy_pop_state();
}
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 314 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    ;
}
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 319 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The software license. */
    codeIdx = 0;
    return TK_COPYING;
}
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 325 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a from-type code block. */
    codeIdx = 0;
    return TK_FROMTYPE;
}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 331 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a to-type code block. */
    codeIdx = 0;
    return TK_TOTYPE;
}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 337 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a to-sub-class code block. */
    codeIdx = 0;
    return TK_TOSUBCLASS;
}
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 343 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of an exported header code block. */
    codeIdx = 0;
    return TK_EXPHEADERCODE;
}
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 349 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of part of an extract. */
    codeIdx = 0;

    BEGIN directive_start;

    return TK_EXTRACT;
}
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 358 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a module header code block. */
    codeIdx = 0;
    return TK_MODHEADERCODE;
}
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 364 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a type header code block. */
    codeIdx = 0;
    return TK_TYPEHEADERCODE;
}
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 370 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a pre-initialisation code block. */
    codeIdx = 0;
    return TK_PREINITCODE;
}
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 376 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of an initialisation code block. */
    codeIdx = 0;
    return TK_INITCODE;
}
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 382 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a post-initialisation code block. */
    codeIdx = 0;
    return TK_POSTINITCODE;
}
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 388 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a class finalisation code block. */
    codeIdx = 0;
    return TK_FINALCODE;
}
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 394 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a unit code block. */
    codeIdx = 0;
    return TK_UNITCODE;
}
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 400 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a unit post-include code block. */
    codeIdx = 0;
    return TK_UNITPOSTINCLUDECODE;
}
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 406 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a module code block. */
    codeIdx = 0;
    return TK_MODCODE;
}
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 412 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a type code block. */
    codeIdx = 0;
    return TK_TYPECODE;
}
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 418 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a C++ method code block. */
    codeIdx = 0;
    return TK_METHODCODE;
}
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 424 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a C++ code block to insert before the MethodCode. */
    codeIdx = 0;
    return TK_PREMETHODCODE;
}
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 430 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a C++ virtual call code block. */
    codeIdx = 0;
    return TK_VIRTUALCALLCODE;
}
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 436 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a C++ virtual code block. */
    codeIdx = 0;
    return TK_VIRTUALCATCHERCODE;
}
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 442 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a traverse code block. */
    codeIdx = 0;
    return TK_TRAVERSECODE;
}
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 448 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a clear code block. */
    codeIdx = 0;
    return TK_CLEARCODE;
}
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 454 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a get buffer code block. */
    codeIdx = 0;
    return TK_GETBUFFERCODE;
}
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 460 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a release buffer code block. */
    codeIdx = 0;
    return TK_RELEASEBUFFERCODE;
}
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 466 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a read buffer code block. */
    codeIdx = 0;
    return TK_READBUFFERCODE;
}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 472 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a write buffer code block. */
    codeIdx = 0;
    return TK_WRITEBUFFERCODE;
}
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 478 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a segment count code block. */
    codeIdx = 0;
    return TK_SEGCOUNTCODE;
}
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 484 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a char buffer code block. */
    codeIdx = 0;
    return TK_CHARBUFFERCODE;
}
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 490 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a create instance code block. */
    codeIdx = 0;
    return TK_INSTANCECODE;
}
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 496 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a pickle code block. */
    codeIdx = 0;
    return TK_PICKLECODE;
}
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 502 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a raise Python exception code block. */
    codeIdx = 0;
    return TK_RAISECODE;
}
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 508 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of an exported type hint code block. */
    codeIdx = 0;
    return TK_EXPTYPEHINTCODE;
}
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 514 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a type hint code block. */
    codeIdx = 0;
    return TK_TYPEHINTCODE;
}
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 520 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a docstring block. */
    codeIdx = 0;

    BEGIN directive_start;

    return TK_DOCSTRING;
}
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 529 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of an access code block. */
    codeIdx = 0;
    return TK_ACCESSCODE;
}
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 535 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a get code block. */
    codeIdx = 0;
    return TK_GETCODE;
}
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 541 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of a set code block. */
    codeIdx = 0;
    return TK_SETCODE;
}
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 547 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The start of part of a virtual error handler. */
    codeIdx = 0;

    BEGIN directive_start;

    return TK_VIRTERRORHANDLER;
}
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 556 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The end of a code block. */
    BEGIN INITIAL;
    codeIdx = -1;
    return TK_END;
}
	YY_BREAK
case 151:
/* rule 151 can match eol */
YY_RULE_SETUP
#line 563 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The end of a code line . */
    struct inputFile *ifp;

    codeLine[codeIdx] = '\n';
    codeLine[codeIdx + 1] = '\0';
    codeIdx = 0;

    ifp = &inputFileStack[currentFile];

    yylval.codeb = sipMalloc(sizeof (codeBlock));

    yylval.codeb->frag = sipStrdup(codeLine);
    yylval.codeb->linenr = ifp->sloc.linenr++;
    yylval.codeb->filename = ifp->sloc.name;

    return TK_CODELINE;
}
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 582 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* The contents of a code line. */
    if (codeIdx == MAX_CODE_LINE_LENGTH)
        fatallex("Line is too long");

    codeLine[codeIdx++] = yytext[0];
}
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 590 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
{
    /* Anything else is returned as is. */
    return yytext[0];
}
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 595 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"
ECHO;
	YY_BREAK
#line 2859 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/lexer.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(code):
case YY_STATE_EOF(ccomment):
case YY_STATE_EOF(directive):
case YY_STATE_EOF(directive_start):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1149 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1149 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 1148);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n, i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) yyalloc(new_size  );

		else
			(yy_start_stack) = (int *) yyrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    static int yy_top_state  (void)
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        yyfree((yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 595 "/private/var/folders/h1/_bwlktg15kldvnwlfn_tc5c00000gn/T/tmp6qho6tcq/sip/code_generator/metasrc/lexer.l"



/*
 * Hook into EOF handling.  Return 0 if there is more to process.
 */

int yywrap(void)
{
    char *cwd;
    struct inputFile *ifp;

    if ((cwd = inputFileStack[currentFile].cwd) != NULL)
        free(cwd);

    ifp = &inputFileStack[currentFile--];

    /* Tell the parser if this is the end of a file. */
    parserEOF(ifp->sloc.name, &ifp->pc);

    /*
     * Tidy up this file.  Note that we don't free the filename as it will
     * still be referenced for use in error messages.
     */
    fclose(yyin);

    /* See if this was the original file. */
    if (currentFile < 0)
        return 1;

    yy_delete_buffer(YY_CURRENT_BUFFER);
    yy_switch_to_buffer(ifp->bs);

    return 0;
}


/*
 * Initialise the lexer.
 */
void initialiseLexer(void)
{
    /* Initialise all the globals. */
    currentFile = -1;
    codeIdx = -1;
    parenDepth = 0;
    allFiles = NULL;
}


/*
 * Get the current source location.
 */
void getSourceLocation(sourceLocation *slp)
{
    int cf;

    /*
     * Assume that we will already have gone past the newline but watch out in
     * case we have gone past the end of the file.
     */
    if ((cf = currentFile) < 0)
    {
        /* This will be valid if we have been called. */
        cf = 0;
    }

    slp->linenr = inputFileStack[cf].sloc.linenr - 1;
    slp->name = inputFileStack[cf].sloc.name;
}


/*
 * Set up an input file to be read by the lexer, opening it if necessary.  TRUE
 * is returned if the file has not already been read.
 */
int setInputFile(FILE *open_fp, parserContext *pc, int optional)
{
    char *cwd, *fullname = NULL;
    FILE *fp = open_fp;

    if (currentFile >= MAX_INCLUDE_DEPTH - 1)
        fatal("Too many nested %%Include, %%OptionalInclude or %%Import statements\n");

    if (fp != NULL || (fp = openFile(pc->filename)) != NULL)
        fullname = sipStrdup(pc->filename);
    else
    {
        char *cwd;

        /* Try the directory that contains the current file. */
        if (currentFile >= 0 && (cwd = inputFileStack[currentFile].cwd) != NULL)
        {
            fullname = concat(cwd, "/", pc->filename, NULL);

            if ((fp = openFile(fullname)) == NULL)
            {
                free(fullname);
                fullname = NULL;
            }
        }
    }

    /* Try the include path if we haven't found anything yet. */
    if (fullname == NULL)
    {
        stringList *sl;

        fullname = NULL;

        for (sl = includeDirList; sl != NULL; sl = sl -> next)
        {
            if (fullname != NULL)
                free(fullname);

            fullname = concat(sl->s, "/", pc->filename, NULL);

            if ((fp = openFile(fullname)) != NULL)
                break;
        }

        if (fp == NULL)
        {
            if (optional)
                return FALSE;

            fatal("Unable to find file \"%s\"\n", pc->filename);
        }
    }

    /*
     * If we have just opened the file, make sure that we haven't already read
     * it.  While it should never happen with normal modules (if the user
     * doesn't specify recursive %Imports or %Includes) it is likely to happen
     * with consolidated modules.
     */
    if (open_fp == NULL)
    {
        stringList *sl;

        for (sl = allFiles; sl != NULL; sl = sl->next)
            if (strcmp(sl->s, fullname) == 0)
            {
                fclose(fp);
                return FALSE;
            }
    }

    /* Remember the filename. */
    appendString(&allFiles, sipStrdup(fullname));

    yyin = fp;

    ++currentFile;

    /* Remember the directory containing the new file and make it "current". */
    if ((cwd = strchr(fullname, '/')) != NULL)
    {
        cwd = sipStrdup(fullname);
        *strrchr(cwd,'/') = '\0';
    }

    inputFileStack[currentFile].sloc.linenr = 1;
    inputFileStack[currentFile].sloc.name = fullname;
    inputFileStack[currentFile].pc = *pc;
    inputFileStack[currentFile].cwd = cwd;

    if (currentFile > 0)
    {
        inputFileStack[currentFile].bs = YY_CURRENT_BUFFER;
        yy_switch_to_buffer(yy_create_buffer(yyin,YY_BUF_SIZE));
    }

    return TRUE;
}


/*
 * Open a file for reading or return NULL if it doesn't exist.  Any other error
 * is fatal.
 */
static FILE *openFile(const char *name)
{
    FILE *fp;

    if ((fp = fopen(name,"r")) == NULL && errno != ENOENT)
        fatal("Error in opening file %s\n",name);

    return fp;
}


/*
 * Handle fatal yacc errors.
 */
void yyerror(char *s)
{
    if (currentFile < 0)
        fatal("%s\n", s);

    fatal("%s:%d: %s\n", inputFileStack[currentFile].sloc.name,
            inputFileStack[currentFile].sloc.linenr, s);
}


/*
 * Handle warnings while parsing.
 */
void yywarning(char *s)
{
    warning(ParserWarning, "%s:%d: %s\n",
            inputFileStack[currentFile].sloc.name,
            inputFileStack[currentFile].sloc.linenr, s);
}


/*
 * Handle deprecation warnings.
 */
void deprecated(const char *msg)
{
    warning(DeprecationWarning, "%s:%d: %s\n",
            inputFileStack[currentFile].sloc.name,
            inputFileStack[currentFile].sloc.linenr, msg);
}


/*
 * Handle fatal lex errors.
 */
static void fatallex(char *s)
{
    fatal("%s:%d: Lexical analyser error: %s\n",
        inputFileStack[currentFile].sloc.name,
        inputFileStack[currentFile].sloc.linenr,
        s);
}


/*
 * Reset the lexer state to INITIAL.  This is used by directives that allow an
 * argument to be given without parentheses to get out of the 'directive_start'
 * state before an opening parenthesis is seen in another context.
 */
void resetLexerState(void)
{
    BEGIN INITIAL;
}

